@@ -52,7 +52,6 @@ package com.openexchange.index.solr.internal.mail.translators;
 import java.util.Date;
 import java.util.Iterator;
 import java.util.Set;
-import org.apache.commons.logging.Log;
 import com.openexchange.index.IndexField;
 import com.openexchange.index.solr.internal.LuceneQueryTools;
 import com.openexchange.index.solr.internal.config.FieldConfiguration;
@@ -87,7 +86,7 @@ import com.openexchange.mail.search.ToTerm;
  */
 public class CustomTranslator implements QueryTranslator {
 
-    private static final Log LOG = com.openexchange.log.Log.loggerFor(CustomTranslator.class);
+    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(CustomTranslator.class);
 
     private Configuration config;
 
@@ -261,7 +260,7 @@ public class CustomTranslator implements QueryTranslator {
         private void appendFlag(MailIndexField mailField, boolean value) {
             Set<String> solrFields = fieldConfig.getSolrFields(mailField);
             if (solrFields == null || solrFields.isEmpty()) {
-                LOG.warn("Did not find index fields for parameter " + mailField.toString() + ". Skipping this field in search query...");
+                LOG.warn("Did not find index fields for parameter {}. Skipping this field in search query...", mailField);
                 return;
             }
 
@@ -273,7 +272,7 @@ public class CustomTranslator implements QueryTranslator {
         public void visit(SizeTerm term) {
             Set<String> solrFields = fieldConfig.getSolrFields(MailIndexField.SIZE);
             if (solrFields == null || solrFields.isEmpty()) {
-                LOG.warn("Did not find index fields for parameter " + MailIndexField.SIZE.toString() + ". Skipping this field in search query...");
+                LOG.warn("Did not find index fields for parameter {}. Skipping this field in search query...", MailIndexField.SIZE);
                 return;
             }
 
@@ -365,7 +364,7 @@ public class CustomTranslator implements QueryTranslator {
         private void appendStringTerm(IndexField indexField, SearchTerm<String> term) {
             Set<String> solrFields = fieldConfig.getSolrFields(indexField);
             if (solrFields == null || solrFields.isEmpty()) {
-                LOG.warn("Did not find index fields for field " + indexField.toString() + ". Skipping this field in search query...");
+                LOG.warn("Did not find index fields for field {}. Skipping this field in search query...", indexField);
                 return;
             }
 
