@@ -98,8 +98,8 @@ public final class FolderJob extends AbstractMailSyncJob {
 
     private static final long serialVersionUID = -4811521171077091128L;
 
-    protected static final org.apache.commons.logging.Log LOG =
-        com.openexchange.log.Log.valueOf(com.openexchange.log.LogFactory.getLog(FolderJob.class));
+    protected static final org.slf4j.Logger LOG =
+        org.slf4j.LoggerFactory.getLogger(FolderJob.class);
 
     protected static final boolean DEBUG = LOG.isDebugEnabled();
 
