@@ -68,13 +68,11 @@ import com.openexchange.mail.MailField;
 import com.openexchange.mail.MailFields;
 import com.openexchange.mail.MailSortField;
 import com.openexchange.mail.OrderDirection;
-import com.openexchange.mail.api.IMailFolderStorage;
 import com.openexchange.mail.api.IMailMessageStorage;
 import com.openexchange.mail.api.IMailMessageStorageBatch;
 import com.openexchange.mail.api.IMailMessageStorageExt;
 import com.openexchange.mail.api.IMailMessageStorageMimeSupport;
 import com.openexchange.mail.api.ISimplifiedThreadStructure;
-import com.openexchange.mail.api.MailAccess;
 import com.openexchange.mail.dataobjects.MailMessage;
 import com.openexchange.mail.dataobjects.MailPart;
 import com.openexchange.mail.dataobjects.compose.ComposedMailMessage;
@@ -239,12 +237,7 @@ public final class SmalMessageStorage extends AbstractSMALStorage implements IMa
                 }
 
                 final QueryParameters parameters = builder.setHandler(SearchHandlers.CUSTOM).setSearchTerm(searchTerm).build();
-                final long start = System.currentTimeMillis();
                 final IndexResult<MailMessage> result = indexAccess.query(parameters, MailIndexField.getFor(fields));
-                if (LOG.isDebugEnabled()) {
-                    final long diff = System.currentTimeMillis() - start;
-                    LOG.debug("Index Query lasted " + diff + "ms.");
-                }
 
                 List<IndexDocument<MailMessage>> documents = result.getResults();
                 List<MailMessage> mails;
@@ -283,7 +276,7 @@ public final class SmalMessageStorage extends AbstractSMALStorage implements IMa
             try {
                 submitFolderJob(folder);
             } catch (final OXException e) {
-                LOG.warn("Could not schedule folder job for folder " + folder + '.', e);
+                LOG.warn("Could not schedule folder job for folder {}.", folder, e);
             }
         }
 
@@ -351,7 +344,7 @@ public final class SmalMessageStorage extends AbstractSMALStorage implements IMa
         try {
             submitFolderJob(folder);
         } catch (final OXException e) {
-            LOG.warn("Could not schedule folder job for folder " + folder + '.', e);
+            LOG.warn("Could not schedule folder job for folder {}.", folder, e);
         }
 
         return messages;
@@ -505,9 +498,7 @@ public final class SmalMessageStorage extends AbstractSMALStorage implements IMa
 
     private void submitJob(final JobInfo jobInfo) throws OXException {
         if (session instanceof FakeSession) {
-            if (LOG.isDebugEnabled()) {
-                LOG.debug("Session is a fake session. Job will not be submitted...");
-            }
+            LOG.debug("Session is a fake session. Job will not be submitted...");
             // FIXME: This is done to prevent loops here and needs a much better solution!
             return;
         }
