@@ -61,7 +61,6 @@ import java.util.concurrent.ConcurrentMap;
 import java.util.concurrent.ExecutionException;
 import java.util.concurrent.ExecutorService;
 import java.util.concurrent.FutureTask;
-import org.apache.commons.logging.Log;
 import org.apache.solr.client.solrj.response.QueryResponse;
 import org.apache.solr.client.solrj.response.UpdateResponse;
 import org.apache.solr.common.SolrInputDocument;
@@ -74,7 +73,6 @@ import com.hazelcast.core.Member;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.exception.OXException;
 import com.openexchange.exception.OXExceptionConstants;
-import com.openexchange.log.LogFactory;
 import com.openexchange.solr.SolrAccessService;
 import com.openexchange.solr.SolrCoreIdentifier;
 import com.openexchange.solr.SolrExceptionCodes;
@@ -89,7 +87,7 @@ import com.openexchange.solr.rmi.RMISolrException;
  */
 public class DelegationSolrAccessImpl implements SolrAccessService {
 
-    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(DelegationSolrAccessImpl.class));
+    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(DelegationSolrAccessImpl.class);
 
     private final EmbeddedSolrAccessImpl embeddedAccess;
 
@@ -116,7 +114,7 @@ public class DelegationSolrAccessImpl implements SolrAccessService {
         } finally {
             if (LOG.isDebugEnabled()) {
                 long diff = System.currentTimeMillis() - start;
-                LOG.debug("Add took " + diff + "ms for 1 document.");
+                LOG.debug("Add took {}ms for 1 document.", diff);
             }
         }
     }
@@ -139,7 +137,7 @@ public class DelegationSolrAccessImpl implements SolrAccessService {
         } finally {
             if (LOG.isDebugEnabled()) {
                 long diff = System.currentTimeMillis() - start;
-                LOG.debug("Add took " + diff + "ms for " + documents.size() + " documents.");
+                LOG.debug("Add took {}ms for {} documents.", diff, documents.size());
             }
         }
     }
@@ -162,7 +160,7 @@ public class DelegationSolrAccessImpl implements SolrAccessService {
         } finally {
             if (LOG.isDebugEnabled()) {
                 long diff = System.currentTimeMillis() - start;
-                LOG.debug("Delete by id took " + diff + "ms.");
+                LOG.debug("Delete by id took {}ms.", diff);
             }
         }
     }
@@ -185,7 +183,7 @@ public class DelegationSolrAccessImpl implements SolrAccessService {
         } finally {
             if (LOG.isDebugEnabled()) {
                 long diff = System.currentTimeMillis() - start;
-                LOG.debug("Delete by query took " + diff + "ms.");
+                LOG.debug("Delete by query took {}ms.", diff);
             }
         }
     }
@@ -206,7 +204,7 @@ public class DelegationSolrAccessImpl implements SolrAccessService {
         } finally {
             if (LOG.isDebugEnabled()) {
                 long diff = System.currentTimeMillis() - start;
-                LOG.debug("Commit took " + diff + "ms.");
+                LOG.debug("Commit took {}ms.", diff);
             }
         }
     }
@@ -229,7 +227,7 @@ public class DelegationSolrAccessImpl implements SolrAccessService {
         } finally {
             if (LOG.isDebugEnabled()) {
                 long diff = System.currentTimeMillis() - start;
-                LOG.debug("Commit took " + diff + "ms.");
+                LOG.debug("Commit took {}ms.", diff);
             }
         }
     }
@@ -250,7 +248,7 @@ public class DelegationSolrAccessImpl implements SolrAccessService {
         } finally {
             if (LOG.isDebugEnabled()) {
                 long diff = System.currentTimeMillis() - start;
-                LOG.debug("Rollback took " + diff + "ms.");
+                LOG.debug("Rollback took {}ms.", diff);
             }
         }
     }
@@ -271,7 +269,7 @@ public class DelegationSolrAccessImpl implements SolrAccessService {
         } finally {
             if (LOG.isDebugEnabled()) {
                 long diff = System.currentTimeMillis() - start;
-                LOG.debug("Optimize took " + diff + "ms.");
+                LOG.debug("Optimize took {}ms.", diff);
             }
         }
     }
@@ -294,7 +292,7 @@ public class DelegationSolrAccessImpl implements SolrAccessService {
         } finally {
             if (LOG.isDebugEnabled()) {
                 long diff = System.currentTimeMillis() - start;
-                LOG.debug("Optimize took " + diff + "ms.");
+                LOG.debug("Optimize took {}ms.", diff);
             }
         }
     }
@@ -318,7 +316,7 @@ public class DelegationSolrAccessImpl implements SolrAccessService {
         } finally {
             if (LOG.isDebugEnabled()) {
                 long diff = System.currentTimeMillis() - start;
-                LOG.debug("Optimize took " + diff + "ms.");
+                LOG.debug("Optimize took {}ms.", diff);
             }
         }
     }
@@ -341,7 +339,7 @@ public class DelegationSolrAccessImpl implements SolrAccessService {
         } finally {
             if (LOG.isDebugEnabled()) {
                 long diff = System.currentTimeMillis() - start;
-                LOG.debug("Query took " + diff + "ms.");
+                LOG.debug("Query took {}ms.", diff);
             }
         }
     }
@@ -458,7 +456,7 @@ public class DelegationSolrAccessImpl implements SolrAccessService {
             solrCores.unlock(identifier.toString());
             if (LOG.isDebugEnabled()) {
                 long diff = System.currentTimeMillis() - start;
-                LOG.debug("getDelegate() lasted " + diff + "ms.");
+                LOG.debug("getDelegate() lasted {}ms.", diff);
             }
         }
     }
@@ -550,9 +548,7 @@ public class DelegationSolrAccessImpl implements SolrAccessService {
                 rmiAccess.pingRmi(identifier);
             } catch (RemoteException e) {
                 rmiAccess = updateRmiCache(server);
-                if (LOG.isDebugEnabled()) {
-                    LOG.debug("Ping failed for remote access on " + server + ". Reconnect.");
-                }
+                LOG.debug("Ping failed for remote access on {}. Reconnect.", server);
             } catch (RMISolrException e) {
                 OXException exception = new OXException(e.getErrorCode(), e.getMessage(), OXExceptionConstants.MESSAGE_ARGS_EMPTY);
                 exception.setPrefix("SOL");
@@ -560,9 +556,7 @@ public class DelegationSolrAccessImpl implements SolrAccessService {
             }
         }
 
-        if (LOG.isDebugEnabled()) {
-            LOG.debug("Returning remote solr access to server " + server + ".");
-        }
+        LOG.debug("Returning remote solr access to server {}.", server);
         return new SolrAccessServiceRmiWrapper(rmiAccess);
     }
 
